AnalyticsDatabase

Struct AnalyticsDatabase 

pub struct AnalyticsDatabase { /* private fields */ }
Analytics database manager

Implementations

Source

impl AnalyticsDatabase

pub async fn new(database_path: &Path) -> Result<Self>

Create a new analytics database connection

Arguments
  • database_path - Path to the SQLite database file (or “:memory:” for in-memory)
Errors

Returns an error if the database connection cannot be established or SQLite pragmas fail to execute.

pub async fn run_migrations(&self) -> Result<()>

Run database migrations

Errors

Returns an error if any migration SQL fails to execute.

pub const fn pool(&self) -> &SqlitePool

Get a reference to the database pool

pub async fn insert_minute_aggregate( &self, agg: &MetricsAggregate, ) -> Result<i64>

Insert a minute-level metrics aggregate

Errors

Returns an error if the database insert fails.

pub async fn insert_minute_aggregates_batch( &self, aggregates: &[MetricsAggregate], ) -> Result<()>

Insert multiple minute-level aggregates in a batch

Errors

Returns an error if any database insert fails; the transaction is rolled back.

pub async fn insert_hour_aggregate( &self, agg: &HourMetricsAggregate, ) -> Result<i64>

Insert an hour-level metrics aggregate

Errors

Returns an error if the database insert fails.

pub async fn insert_day_aggregate( &self, agg: &DayMetricsAggregate, ) -> Result<i64>

Insert a day-level metrics aggregate

Errors

Returns an error if the database insert fails.

pub async fn upsert_endpoint_stats(&self, stats: &EndpointStats) -> Result<()>

Insert or update endpoint statistics

Errors

Returns an error if the database upsert fails.

pub async fn insert_error_event(&self, error: &ErrorEvent) -> Result<i64>

Insert an error event

Errors

Returns an error if the database insert fails.

pub async fn insert_traffic_pattern( &self, pattern: &TrafficPattern, ) -> Result<()>

Insert a traffic pattern

Errors

Returns an error if the database upsert fails.

pub async fn insert_snapshot(&self, snapshot: &AnalyticsSnapshot) -> Result<i64>

Insert an analytics snapshot

Errors

Returns an error if the database insert fails.

pub async fn get_minute_aggregates( &self, filter: &AnalyticsFilter, ) -> Result<Vec<MetricsAggregate>>

Get minute aggregates for a time range

Errors

Returns an error if the database query fails.

pub async fn get_hour_aggregates( &self, filter: &AnalyticsFilter, ) -> Result<Vec<HourMetricsAggregate>>

Get hour-level aggregates

Errors

Returns an error if the database query fails.

pub async fn get_top_endpoints( &self, limit: i64, workspace_id: Option<&str>, ) -> Result<Vec<EndpointStats>>

Get top endpoints by request count

Errors

Returns an error if the database query fails.

pub async fn get_recent_errors( &self, limit: i64, filter: &AnalyticsFilter, ) -> Result<Vec<ErrorEvent>>

Get recent error events

Errors

Returns an error if the database query fails.

pub async fn get_traffic_patterns( &self, days: i64, workspace_id: Option<&str>, ) -> Result<Vec<TrafficPattern>>

Get traffic patterns for heatmap

Errors

Returns an error if the database query fails.

pub async fn cleanup_minute_aggregates(&self, days: u32) -> Result<u64>

Delete old minute aggregates

Errors

Returns an error if the database delete fails.

pub async fn cleanup_hour_aggregates(&self, days: u32) -> Result<u64>

Delete old hour aggregates

Errors

Returns an error if the database delete fails.

pub async fn cleanup_error_events(&self, days: u32) -> Result<u64>

Delete old error events

Errors

Returns an error if the database delete fails.

pub async fn vacuum(&self) -> Result<()>

Vacuum the database to reclaim space

Errors

Returns an error if the VACUUM command fails.

Source

impl AnalyticsDatabase

pub async fn record_scenario_usage( &self, scenario_id: &str, workspace_id: Option<&str>, org_id: Option<&str>, ) -> Result<()>

Record scenario usage

Errors

Returns an error if the database operation fails.

pub async fn record_persona_ci_hit( &self, persona_id: &str, workspace_id: Option<&str>, org_id: Option<&str>, ci_run_id: Option<&str>, ) -> Result<()>

Record persona CI hit

Errors

Returns an error if the database insert fails.

pub async fn record_endpoint_coverage( &self, endpoint: &str, method: Option<&str>, protocol: &str, workspace_id: Option<&str>, org_id: Option<&str>, coverage_percentage: Option<f64>, ) -> Result<()>

Record endpoint test coverage

Errors

Returns an error if the database operation fails.

pub async fn record_reality_level_staleness( &self, workspace_id: &str, org_id: Option<&str>, endpoint: Option<&str>, method: Option<&str>, protocol: Option<&str>, current_reality_level: Option<&str>, staleness_days: Option<i32>, ) -> Result<()>

Record reality level staleness

Errors

Returns an error if the database insert fails.

pub async fn record_drift_percentage( &self, workspace_id: &str, org_id: Option<&str>, total_mocks: i64, drifting_mocks: i64, ) -> Result<()>

Record drift percentage metrics

Errors

Returns an error if the database insert fails.

pub async fn get_scenario_usage( &self, workspace_id: Option<&str>, org_id: Option<&str>, limit: Option<i64>, ) -> Result<Vec<ScenarioUsageMetrics>>

Get scenario usage metrics

Errors

Returns an error if the database query fails.

pub async fn get_persona_ci_hits( &self, workspace_id: Option<&str>, org_id: Option<&str>, limit: Option<i64>, ) -> Result<Vec<PersonaCIHit>>

Get persona CI hits

Errors

Returns an error if the database query fails.

pub async fn get_endpoint_coverage( &self, workspace_id: Option<&str>, org_id: Option<&str>, min_coverage: Option<f64>, ) -> Result<Vec<EndpointCoverage>>

Get endpoint coverage

Errors

Returns an error if the database query fails.

pub async fn get_reality_level_staleness( &self, workspace_id: Option<&str>, org_id: Option<&str>, max_staleness_days: Option<i32>, ) -> Result<Vec<RealityLevelStaleness>>

Get reality level staleness

Errors

Returns an error if the database query fails.

pub async fn get_drift_percentage( &self, workspace_id: Option<&str>, org_id: Option<&str>, limit: Option<i64>, ) -> Result<Vec<DriftPercentageMetrics>>

Get drift percentage metrics

Errors

Returns an error if the database query fails.

Source

impl AnalyticsDatabase

pub async fn export_to_csv<W: Write>( &self, writer: &mut W, filter: &AnalyticsFilter, ) -> Result<usize>

Export metrics to CSV format

Errors

Returns an error if the database query or CSV writing fails.

pub async fn export_to_json(&self, filter: &AnalyticsFilter) -> Result<String>

Export metrics to JSON format

Errors

Returns an error if the database query or JSON serialization fails.

pub async fn export_endpoints_to_csv<W: Write>( &self, writer: &mut W, workspace_id: Option<&str>, limit: i64, ) -> Result<usize>

Export endpoint stats to CSV

Errors

Returns an error if the database query or CSV writing fails.

pub async fn export_errors_to_csv<W: Write>( &self, writer: &mut W, filter: &AnalyticsFilter, limit: i64, ) -> Result<usize>

Export error events to CSV

Errors

Returns an error if the database query or CSV writing fails.

Source

impl AnalyticsDatabase

pub async fn record_pillar_usage(&self, event: &PillarUsageEvent) -> Result<()>

Record a pillar usage event

Errors

Returns an error if the database insert or JSON serialization fails.

pub async fn get_workspace_pillar_metrics( &self, workspace_id: &str, duration_seconds: i64, ) -> Result<PillarUsageMetrics>

Get pillar usage metrics for a workspace

Errors

Returns an error if any database query fails.

pub async fn get_org_pillar_metrics( &self, org_id: &str, duration_seconds: i64, ) -> Result<PillarUsageMetrics>

Get pillar usage metrics for an organization

Errors

Returns an error if any database query fails.

Source

impl AnalyticsDatabase

pub async fn get_overview_metrics( &self, duration_seconds: i64, ) -> Result<OverviewMetrics>

Get overview metrics for the dashboard

Errors

Returns an error if any database query fails.

pub async fn get_top_protocols( &self, limit: i64, workspace_id: Option<&str>, ) -> Result<Vec<ProtocolStat>>

Get top protocols by request count

Errors

Returns an error if the database query fails.

pub async fn get_request_time_series( &self, filter: &AnalyticsFilter, granularity: Granularity, ) -> Result<Vec<TimeSeries>>

Get request count time series

Errors

Returns an error if the database query fails.

Get latency trends

Errors

Returns an error if the database query fails.

pub async fn get_error_summary( &self, filter: &AnalyticsFilter, limit: i64, ) -> Result<Vec<ErrorSummary>>

Get error summary

Errors

Returns an error if the database query fails.