pub async fn init(config: AnalyticsConfig) -> Result<AnalyticsDatabase>Expand description
Initialize the analytics system with the given configuration
Errors
Returns an error if the database cannot be opened or migrations fail.
pub async fn init(config: AnalyticsConfig) -> Result<AnalyticsDatabase>Initialize the analytics system with the given configuration
Returns an error if the database cannot be opened or migrations fail.